package com.cardiff.client_project.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.core.GrantedAuthorityDefaults;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.security.web.access.AccessDeniedHandler;
import org.springframework.stereotype.Component;

@Component
public class WebSecurityConfig{

    //exception handler
    @Autowired
    //Unauthenticated exception filter
    private  CustomAuthenticationEntryPoint customAuthenticationEntryPoint;
    @Autowired
    //Insufficient permission exception processor
    private  AccessDeniedHandler customAccessDeniedHandler;

    /**
     * Coded filter
     * @return
     */
    @Bean
    public PasswordEncoder passwordEncoder() {
        return new BCryptPasswordEncoder();
    }

    /**
     * Delete the default ROLE_ prefix
     * @return
     */
    @Bean
    public GrantedAuthorityDefaults grantedAuthorityDefaults(){
        return new GrantedAuthorityDefaults("");
    }


    /**
     * Set filter chain
     * @param http
     * @return
     * @throws Exception
     */
    @Bean
    public SecurityFilterChain securityFilterChain(HttpSecurity http) throws Exception {
    // Turn off the csrf mechanism, you can use get login, otherwise you can only use post
        http    .csrf(csrf-> csrf.disable())
                .authorizeHttpRequests(requests -> requests
                        .requestMatchers("/superAdminView.html").hasRole("SUPER")
                        .requestMatchers("/hospitalView.html").hasRole("HOSPITAL")
                        //.requestMatchers("/admin.html").hasRole("ADMIN")
                        .anyRequest().permitAll()

                )
                //Custom permission exception handler
                .exceptionHandling(exceptions -> exceptions
                        .authenticationEntryPoint(customAuthenticationEntryPoint)
                        .accessDeniedHandler(customAccessDeniedHandler)
                )
                .logout(log -> log
                        .logoutUrl("/logout")               // Set a logoff request URL
                        .logoutSuccessUrl("/login.html")  // Redirection after successful logout URL
                        .invalidateHttpSession(true)       // Invalid session on logout
                        .clearAuthentication(true)         // Clear authentication information
                        .deleteCookies("JSESSIONID")       // delete Cookie
                )
                .formLogin(form -> form
                        .loginPage("/login")
                        .successHandler(new AuthenticationSuccessHandler())
                        .failureHandler(new AuthenticationFailHandler())
                        .permitAll());

        return http.build();
    }
}



