package com.cardiff.client_project.service.imp;

import com.cardiff.client_project.mapper.CommonAdminHospitalMapper;
import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.pojo.vo.NurseVO;
import com.cardiff.client_project.service.CommonAdminHospitalService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CommonAdminHospitalServiceImp implements CommonAdminHospitalService {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Autowired
    private CommonAdminHospitalMapper commonAdminHospitalMapper;

    @Override
    public List<HospitalDTO> getAllHospitals() {
        String sql = "SELECT * FROM hospital";
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class));
    }

    @Override
    public List<HospitalDTO> searchHospitals(String name, String location) {
        StringBuilder sql = new StringBuilder("SELECT * FROM hospital WHERE 1=1");
        if (name != null && !name.isEmpty()) {
            sql.append(" AND name LIKE ?");
        }
        if (location != null && !location.isEmpty()) {
            sql.append(" AND address LIKE ?");
        }
        return jdbcTemplate.query(sql.toString(), new BeanPropertyRowMapper<>(HospitalDTO.class),
                name != null ? "%" + name + "%" : null,
                location != null ? "%" + location + "%" : null);
    }

    @Override
    public void addHospital(HospitalDTO hospital) {
        if (hospital.getName() == null || hospital.getAddress() == null ||
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 ||
                hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        String sql = "INSERT INTO hospital (name, address, phone, maxAmount, amountPatient) VALUES (?, ?, ?, ?, ?)";
        jdbcTemplate.update(sql,
                hospital.getName(),
                hospital.getAddress(),
                hospital.getPhone(),
                hospital.getTotalBeds(),
                hospital.getAvailableBeds()
        );
    }

    @Override
    public Result add(Object entity) {
        return null;
    }

    @Override
    public void updateHospital(HospitalDTO hospital) {

    }

    @Override
    public void editHospital(HospitalDTO hospital) {
        if (hospital.getId() <= 0 || hospital.getName() == null || hospital.getAddress() == null ||
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 || hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        // 更新占用率计算（可选，具体依项目需求）
        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        // SQL 语句更新医院数据
        String sql = "UPDATE hospital SET name = ?, address = ?, phone = ?, maxAmount = ?, amountPatient = ? WHERE id = ?";
        jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), hospital.getId());
    }

    @Override
    public void deleteHospital(int id) {
        String deleteSql = "DELETE FROM hospital WHERE id = ?";
        jdbcTemplate.update(deleteSql, id);
    }

    @Override
    public HospitalDTO getHospitalById(int id) {
        String sql = "SELECT * FROM hospital WHERE id = ?";
        List<HospitalDTO> hospitals = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class), id);
        return hospitals.isEmpty() ? null : hospitals.get(0);
    }


    @Override
    public void resetHospitalIds() {
        try {
            // Step 1: 创建一个变量用于更新行号
            String setRowNumber = "SET @row_number = 0;";
            jdbcTemplate.execute(setRowNumber);

            // Step 2: 重新更新表的 ID 顺序
            String updateIds = "UPDATE hospital SET id = (@row_number := @row_number + 1);";
            jdbcTemplate.execute(updateIds);

            // Step 3: 重置 AUTO_INCREMENT
            String resetAutoIncrement = "ALTER TABLE hospital AUTO_INCREMENT = 1;";
            jdbcTemplate.execute(resetAutoIncrement);

            System.out.println("Hospital IDs reset successfully.");
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("Failed to reset hospital IDs: " + e.getMessage());
        }
    }


    @Override
    public List<NurseVO> getAllNurses() {
        return commonAdminHospitalMapper.findAllNurses();
    }

    @Override
    public List<NurseVO> searchNurses(String name, Integer hospitalId) {
        return commonAdminHospitalMapper.searchNurses(name, hospitalId);
    }

}
